@@ -15,20 +15,20 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from typing import Dict, Optional
+from typing import Optional
 
 from requests.auth import AuthBase
 
 
-class AuthInfo(object):
+class AuthInfo:
     """Authentication information."""
 
-    headers: Optional[Dict[str, str]]
+    headers: Optional[dict[str, str]]
     auth: Optional[AuthBase]
 
     def __init__(
         self,
-        headers: Optional[Dict[str, str]] = None,
+        headers: Optional[dict[str, str]] = None,
         auth: Optional[AuthBase] = None,
     ) -> None:
         """Instanciate an Authentication information.
