@@ -32,10 +32,11 @@ LEVELS = MappingProxyType({
     'developer': 30,
     'maintainer': 40,
     'owner': 50,
+    'admin': 60,
 })
 
 
-def access_level(level: str) -> Optional[int]:
+def access_level_value(level: str) -> Optional[int]:
     """Convert access level to int.
 
     Args:
