@@ -18,13 +18,14 @@
 import logging
 from copy import deepcopy
 
-from gitlabracadabra.gitlab.access_levels import access_level
+from gitlabracadabra.gitlab.access_levels import access_level_value
+from gitlabracadabra.objects.object import GitLabracadabraObject
 
 
 logger = logging.getLogger(__name__)
 
 
-class GroupsMixin(object):
+class GroupsMixin(GitLabracadabraObject):
     """Object with groups."""
 
     """_process_groups()
@@ -53,7 +54,7 @@ class GroupsMixin(object):
                 group['group_full_path'] = self.connection.group_cache.full_path_from_id(group['group_id'])
             self.connection.group_cache.map_group(group['group_id'], group['group_full_path'])
             if group['group_full_path'] in param_value.keys():
-                target_access_level = access_level(param_value[group['group_full_path']])
+                target_access_level = access_level_value(param_value[group['group_full_path']])
                 if group['group_access_level'] != target_access_level:
                     if dry_run:
                         logger.info('[%s] NOT Changing group %s access level: %s -> %s (dry-run)',
@@ -85,7 +86,7 @@ class GroupsMixin(object):
                 logger.warning('[%s] Group not found %s',
                                self._name, group_full_path)
                 continue
-            target_access_level = access_level(target_group_access)
+            target_access_level = access_level_value(target_group_access)
             if dry_run:
                 logger.info('[%s] NOT Sharing group %s: %s -> %s (dry-run)',
                             self._name, group_full_path,
