@@ -19,11 +19,13 @@
 import logging
 from copy import deepcopy
 
+from gitlabracadabra.objects.object import GitLabracadabraObject
+
 
 logger = logging.getLogger(__name__)
 
 
-class LabelsMixin(object):
+class LabelsMixin(GitLabracadabraObject):
     """Object with labels."""
 
     """_process_labels()
