@@ -20,13 +20,14 @@ from copy import deepcopy
 
 from gitlab.exceptions import GitlabDeleteError
 
-from gitlabracadabra.gitlab.access_levels import access_level
+from gitlabracadabra.gitlab.access_levels import access_level_value
+from gitlabracadabra.objects.object import GitLabracadabraObject
 
 
 logger = logging.getLogger(__name__)
 
 
-class MembersMixin(object):
+class MembersMixin(GitLabracadabraObject):
     """Object with members."""
 
     """_process_members()
@@ -43,7 +44,7 @@ class MembersMixin(object):
         for _member_username, member in sorted(current_members.items()):
             self.connection.user_cache.map_user(member.id, member.username)
             if member.username in param_value.keys():
-                target_access_level = access_level(param_value[member.username])
+                target_access_level = access_level_value(param_value[member.username])
                 if member.access_level != target_access_level:
                     if dry_run:
                         logger.info('[%s] NOT Changing user %s (%s) access level: %s -> %s (dry-run)',
@@ -79,7 +80,7 @@ class MembersMixin(object):
                 logger.warning('[%s] User not found %s',
                                self._name, target_username)
                 continue
-            target_access_level = access_level(target_user_access)
+            target_access_level = access_level_value(target_user_access)
             if dry_run:
                 logger.info('[%s] NOT Adding user %s: %s -> %s (dry-run)',
                             self._name, target_username, 0, target_access_level)
