@@ -19,11 +19,13 @@
 import logging
 from copy import deepcopy
 
+from gitlabracadabra.objects.object import GitLabracadabraObject
+
 
 logger = logging.getLogger(__name__)
 
 
-class MilestonesMixin(object):
+class MilestonesMixin(GitLabracadabraObject):
     """Object with milestones."""
 
     """_process_milestones()
