@@ -19,11 +19,13 @@
 import logging
 from copy import deepcopy
 
+from gitlabracadabra.objects.object import GitLabracadabraObject
+
 
 logger = logging.getLogger(__name__)
 
 
-class PipelineSchedulesMixin(object):
+class PipelineSchedulesMixin(GitLabracadabraObject):
     """Object with pipeline schedules."""
 
     """_process_pipeline_schedules()
