@@ -19,11 +19,13 @@
 import logging
 from copy import deepcopy
 
+from gitlabracadabra.objects.object import GitLabracadabraObject
+
 
 logger = logging.getLogger(__name__)
 
 
-class VariablesMixin(object):
+class VariablesMixin(GitLabracadabraObject):
     """Object with variables."""
 
     """_process_variables()
