@@ -19,11 +19,13 @@
 import logging
 from copy import deepcopy
 
+from gitlabracadabra.objects.object import GitLabracadabraObject
+
 
 logger = logging.getLogger(__name__)
 
 
-class WebhooksMixin(object):
+class WebhooksMixin(GitLabracadabraObject):
     """Object with webhooks."""
 
     """_process_webhooks()
