@@ -22,7 +22,7 @@ from typing import Optional
 
 from requests import RequestException, codes
 
-from gitlabracadabra.auth_info import AuthInfo
+from gitlabracadabra import __version__ as gitlabracadabra_version
 from gitlabracadabra.packages.package_file import PackageFile
 from gitlabracadabra.packages.source import Source
 from gitlabracadabra.packages.stream import Stream
@@ -32,7 +32,7 @@ from gitlabracadabra.session import Session
 logger = getLogger(__name__)
 
 
-class Destination(object):
+class Destination:
     """Destination package repository."""
 
     def __init__(
@@ -46,11 +46,12 @@ class Destination(object):
             log_prefix: Log prefix.
         """
         self._log_prefix = log_prefix
-        self._session = Session()
+        self.session = Session()
+        self.session.headers['User-Agent'] = 'gitlabracadabra/{0}'.format(gitlabracadabra_version)
 
     def __del__(self) -> None:  # noqa:WPS603
-        """Destroy a registry connection."""
-        self._session.close()
+        """Destroy a connection."""
+        self.session.close()
 
     def import_source(self, source: Source, *, dry_run: bool) -> None:
         """Import package files from Source.
@@ -61,7 +62,7 @@ class Destination(object):
         """
         try:
             for package_file in source.package_files:
-                self.try_import_package_file(package_file, dry_run=dry_run)
+                self.try_import_package_file(source, package_file, dry_run=dry_run)
         except RequestException as err:
             if err.request:
                 logger.warning(
@@ -80,15 +81,16 @@ class Destination(object):
                     repr(err),
                 )
 
-    def try_import_package_file(self, package_file: PackageFile, *, dry_run: bool) -> None:
+    def try_import_package_file(self, source: Source, package_file: PackageFile, *, dry_run: bool) -> None:
         """Try to import one package file, and catch RequestExceptions.
 
         Args:
+            source: Source repository.
             package_file: Source package file.
             dry_run: Dry run.
         """
         try:
-            self.import_package_file(package_file, dry_run=dry_run)
+            self.import_package_file(source, package_file, dry_run=dry_run)
         except RequestException as err:
             if err.request:
                 logger.warning(
@@ -113,15 +115,16 @@ class Destination(object):
                     repr(err),
                 )
 
-    def import_package_file(self, package_file: PackageFile, *, dry_run: bool) -> None:
+    def import_package_file(self, source: Source, package_file: PackageFile, *, dry_run: bool) -> None:
         """Import one package file.
 
         Args:
+            source: Source repository.
             package_file: Source package file.
             dry_run: Dry run.
         """
         # Test source exists
-        if not self._source_package_file_exists(package_file):
+        if not self._source_package_file_exists(source, package_file):
             return
 
         # Test destination exists
@@ -133,7 +136,7 @@ class Destination(object):
             return
 
         # Upload
-        self._upload_package_file(package_file)
+        self._upload_package_file(source, package_file)
 
     def upload_method(self, package_file: PackageFile) -> str:
         """Get upload HTTP method.
@@ -179,19 +182,8 @@ class Destination(object):
         """
         return None  # noqa: WPS324
 
-    def auth_info(self, package_file: PackageFile) -> AuthInfo:
-        """Get auth info when testing existence and uploading.
-
-        Args:
-            package_file: Source package file.
-
-        Returns:
-            An AuthInfo.
-        """
-        return AuthInfo()
-
-    def _source_package_file_exists(self, package_file: PackageFile) -> bool:
-        source_exists_response = self._session.request(
+    def _source_package_file_exists(self, source: Source, package_file: PackageFile) -> bool:
+        source_exists_response = source.session.request(
             'HEAD',
             package_file.url,
         )
@@ -222,13 +214,10 @@ class Destination(object):
         return False
 
     def _destination_package_file_exists(self, package_file: PackageFile) -> bool:
-        auth_info = self.auth_info(package_file)
         head_url = self.head_url(package_file)
-        destination_exists_response = self._session.request(
+        destination_exists_response = self.session.request(
             'HEAD',
             head_url,
-            headers=auth_info.headers,
-            auth=auth_info.auth,
         )
         if destination_exists_response.status_code == codes['ok']:
             return True
@@ -260,8 +249,7 @@ class Destination(object):
             )
         return dry_run
 
-    def _upload_package_file(self, package_file: PackageFile) -> None:  # noqa: WPS210
-        auth_info = self.auth_info(package_file)
+    def _upload_package_file(self, source: Source, package_file: PackageFile) -> None:  # noqa: WPS210
         upload_method = self.upload_method(package_file)
         upload_url = self.upload_url(package_file)
         files_key = self.files_key(package_file)
@@ -275,7 +263,7 @@ class Destination(object):
             package_file.package_version,
             package_file.url,
         )
-        download_response = self._session.request(
+        download_response = source.session.request(
             'GET',
             package_file.url,
             stream=True,
@@ -285,20 +273,16 @@ class Destination(object):
         )
 
         if files_key:
-            upload_response = self._session.request(
+            upload_response = self.session.request(
                 upload_method,
                 upload_url,
                 files={files_key: Stream(download_response)},  # type: ignore
-                headers=auth_info.headers,
-                auth=auth_info.auth,
             )
         else:
-            upload_response = self._session.request(
+            upload_response = self.session.request(
                 upload_method,
                 upload_url,
                 data=Stream(download_response),
-                headers=auth_info.headers,
-                auth=auth_info.auth,
             )
         if upload_response.status_code not in {codes['created'], codes['accepted']}:
             logger.warning(
