@@ -16,20 +16,24 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
 import re
+from io import TextIOWrapper
 
 import yaml
 
 from gitlabracadabra.dictutils import update_dict_with_defaults
+from gitlabracadabra.objects.object import GitLabracadabraObject
 
 
 class GitlabracadabraParser(object):
     """YAML parser."""
 
-    def __init__(self, action_file, config, recursion=0):
+    def __init__(self, action_file: str, config: dict, recursion: int = 0) -> None:
         self._action_file = action_file
         self._config = config
-        self._objects = None
+        self._objects: dict[str, GitLabracadabraObject] | None = None
         self._include = self._config.pop('include', [])
         for included in self._include:
             if recursion >= 10:
@@ -47,12 +51,17 @@ class GitlabracadabraParser(object):
             update_dict_with_defaults(self._config, included._config)
 
     @classmethod
-    def from_yaml(cls, action_file, yaml_blob, recursion=0):
+    def from_yaml(
+        cls,
+        action_file: str,
+        yaml_blob: str | TextIOWrapper,
+        recursion: int = 0,
+    ) -> GitlabracadabraParser:
         config = yaml.safe_load(yaml_blob)
         return GitlabracadabraParser(action_file, config, recursion)
 
     @classmethod
-    def from_yaml_file(cls, action_file, recursion=0):
+    def from_yaml_file(cls, action_file: str, recursion: int = 0) -> GitlabracadabraParser:
         with open(action_file) as yaml_blob:
             return cls.from_yaml(action_file, yaml_blob, recursion)
 
@@ -102,7 +111,7 @@ class GitlabracadabraParser(object):
     Converts object-type to GitLabracadabraObjectType.
     """
     @classmethod
-    def _type_to_classname(cls, obj_type):
+    def _type_to_classname(cls, obj_type: str) -> str:
         splitted = re.split('[-_]', obj_type)
         mapped = (s[0].upper() + s[1:].lower() for s in splitted)
         return 'GitLabracadabra' + ''.join(mapped)
@@ -112,7 +121,7 @@ class GitlabracadabraParser(object):
     Converts object-type to gitlabracadabra.objects.object_type.
     """
     @classmethod
-    def _type_to_module(cls, obj_type):
+    def _type_to_module(cls, obj_type: str) -> str:
         return 'gitlabracadabra.objects.' + obj_type.lower().replace('-', '_')
 
     """get_class_for()
@@ -120,20 +129,20 @@ class GitlabracadabraParser(object):
     Get the class for the given object type.
     """
     @classmethod
-    def get_class_for(cls, obj_type):
+    def get_class_for(cls, obj_type: str) -> type[GitLabracadabraObject]:
         obj_classname = cls._type_to_classname(obj_type)
         obj_module = __import__(cls._type_to_module(obj_type), globals(), locals(), [obj_classname])
-        return getattr(obj_module, obj_classname)
+        return getattr(obj_module, obj_classname)  # type: ignore
 
     """objects()
 
     Returns .
     """
-    def objects(self):
+    def objects(self) -> dict[str, GitLabracadabraObject]:
         if self._objects is not None:
             return self._objects
         self._objects = {}
-        for k, v in self._items():
+        for k, v in self._items():  # type:ignore
             if 'type' in v:
                 obj_type = v['type']
                 v.pop('type')
