@@ -16,9 +16,11 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from collections import namedtuple
+from unittest import skipIf
 from unittest.mock import MagicMock, call, patch
 
 from semantic_version import __version__ as semantic_version_version
+from vcr import __version__ as vcr_version
 
 from gitlabracadabra.containers.registries import Registries
 from gitlabracadabra.containers.registry import Registry
@@ -229,6 +231,7 @@ class TestProjectImageMirrors(TestCaseWithManager):
                     self._assert_mappings(registry, import_manifest_mock, test_data.mappings)
         self.assertTrue(cass.all_played)
 
+    @skipIf(vcr_version == '6.0.1', 'vcrpy without iterator support https://github.com/kevin1024/vcrpy/pull/851')
     @my_vcr.use_cassette
     def test_image_mirrors_auth(self, cass):
         """Test image_mirrors, auth'ing using JWT.
@@ -262,6 +265,7 @@ class TestProjectImageMirrors(TestCaseWithManager):
                 )])
         self.assertTrue(cass.all_played)
 
+    @skipIf(vcr_version == '6.0.1', 'vcrpy without iterator support https://github.com/kevin1024/vcrpy/pull/851')
     @my_vcr.use_cassette
     def test_image_mirror_digest(self, cass):
         """Test image_mirrors, with source digest.
@@ -293,6 +297,7 @@ class TestProjectImageMirrors(TestCaseWithManager):
                 )])
         self.assertTrue(cass.all_played)
 
+    @skipIf(vcr_version == '6.0.1', 'vcrpy without iterator support https://github.com/kevin1024/vcrpy/pull/851')
     @my_vcr.use_cassette
     def test_image_mirror_no_digest_header(self, cass):
         """Test image_mirrors, without Docker-Content-Digest header.
@@ -324,6 +329,7 @@ class TestProjectImageMirrors(TestCaseWithManager):
                 )])
         self.assertTrue(cass.all_played)
 
+    @skipIf(vcr_version == '6.0.1', 'vcrpy without iterator support https://github.com/kevin1024/vcrpy/pull/851')
     @my_vcr.use_cassette
     def test_image_mirror_manifest_v1(self, cass):
         """Test image_mirrors, application/vnd.docker.distribution.manifest.v1+prettyjws.
@@ -354,6 +360,7 @@ class TestProjectImageMirrors(TestCaseWithManager):
                     '-4+0+-3=-7 uploaded+mounted+existing blobs size',  # 14173208+0+96=14173304
                 )])
 
+    @skipIf(vcr_version == '6.0.1', 'vcrpy without iterator support https://github.com/kevin1024/vcrpy/pull/851')
     @my_vcr.use_cassette
     def test_image_mirrors_mounted(self, cass):
         """Test image_mirrors, with mounted blobs.
@@ -386,6 +393,7 @@ class TestProjectImageMirrors(TestCaseWithManager):
                 )])
         self.assertTrue(cass.all_played)
 
+    @skipIf(vcr_version == '6.0.1', 'vcrpy without iterator support https://github.com/kevin1024/vcrpy/pull/851')
     @my_vcr.use_cassette
     def test_image_mirrors_redirect(self, cass):
         """Test image_mirrors, with redirect.
